SwimR-package:
SwimR: A Suite of Analytical Tools for Quantification of C. elegans Swimming Behavior
Description
SwimR is an R-based suite that calculates, analyses, and plots the frequency of
C. elegans swimming behavior over time. It places a particular emphasis on
identifying paralysis and quantifying the kinetic elements of paralysis
during swimming. Data is input to SwipR from a custom built program that
fits a 5 point morphometric spine to videos of single worms swimming
in a buffer called Worm Tracker.
Details
|
Package: |
| SwimR |
|
Type: |
| Package |
|
Version: |
| 0.99.1 |
|
Date: |
| 2013-08-17 |
|
License: |
| LGPL (>= 2) |
|
LazyLoad: |
| yes |
References
An Open-Source Analytical Platform for Analysis of C. elegans Swimming
Induced Paralysis (under reivew).